<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP">
<context>
    <name>LinetypeSettings</name>
    <message>
        <location filename="../LinetypeSettings.js" line="+25"/>
        <source>Defaults for New Drawings</source>
        <translation>新規図面へのデフォルト</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+2"/>
        <source>Linetype</source>
        <translation>ラインタイプ</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>General</source>
        <translation>一般</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+19"/>
        <source>Global Linetype Scale:</source>
        <translation>グローバルラインタイプの縮尺:</translation>
    </message>
    <message>
        <location line="+35"/>
        <source>Scale of linetypes matches the scale of each viewport</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
